%global gname haclient
%global uname hacluster
%global pcmk_docdir %{_docdir}/%{name}

%global specversion 7
%global upstream_version 394e906
%global upstream_prefix ClusterLabs-pacemaker

# Compatibility macros for distros (fedora) that don't provide Python macros by default
# Do this instead of trying to conditionally include {_rpmconfigdir}/macros.python
%{!?py_ver:     %{expand: %%global py_ver      %%(echo `python -c "import sys; print sys.version[:3]"`)}}
%{!?py_prefix:  %{expand: %%global py_prefix   %%(echo `python -c "import sys; print sys.prefix"`)}}
%{!?py_libdir:  %{expand: %%global py_libdir   %%{expand:%%%%{py_prefix}/%%%%{_lib}/python%%%%{py_ver}}}}
%{!?py_sitedir: %{expand: %%global py_sitedir  %%{expand:%%%%{py_libdir}/site-packages}}}

# Turn off the auto compilation of python files not in the site-packages directory
# Needed so that the -devel package is multilib compliant
%global __os_install_post %(echo '%{__os_install_post}' | sed -e 's!/usr/lib[^[:space:]]*/brp-python-bytecompile[[:space:]].*$!!g')

# Compatibility macro wrappers for legacy RPM versions that do not
# support conditional builds
%{!?bcond_without: %{expand: %%global bcond_without() %%{expand:%%%%{!?_without_%%{1}:%%%%global with_%%{1} 1}}}}
%{!?bcond_with:    %{expand: %%global bcond_with()    %%{expand:%%%%{?_with_%%{1}:%%%%global with_%%{1} 1}}}}
%{!?with:          %{expand: %%global with()          %%{expand:%%%%{?with_%%{1}:1}%%%%{!?with_%%{1}:0}}}}
%{!?without:       %{expand: %%global without()       %%{expand:%%%%{?with_%%{1}:0}%%%%{!?with_%%{1}:1}}}}

%global cs_major %(pkg-config corosync --modversion  | awk -F . '{print $1}')
%global cs_minor %(pkg-config corosync --modversion  | awk -F . '{print $2}')
%global rawhide  %(test ! -e /etc/yum.repos.d/fedora-rawhide.repo; echo $?)

# Conditionals
# Invoke "rpmbuild --without <feature>" or "rpmbuild --with <feature>"
# to disable or enable specific features

# Supported cluster stacks, must support at least one
%bcond_without corosync
%bcond_with heartbeat
%bcond_without cman

# Legacy stonithd fencing agents
%bcond_with stonithd

# ESMTP is not available in RHEL, only in EPEL. Allow people to build
# the RPM without ESMTP in case they choose not to use EPEL packages
%bcond_with esmtp
%bcond_with snmp

# Build with/without support for profiling tools
%bcond_with profiling
%bcond_with gcov

# We generate docs using Publican, Asciidoc and Inkscape, but they're not available everywhere
%bcond_without doc

# Use a different versioning scheme
%bcond_with pre_release

%if %{with profiling}
# This disables -debuginfo package creation and also the stripping binaries/libraries
# Useful if you want sane profiling data
%global debug_package %{nil}
%endif

%if %{with pre_release}
%global pcmk_release 0.%{specversion}.%{upstream_version}.git
%else
%global pcmk_release %{specversion}
%endif

Name:          pacemaker
Summary:       Scalable High-Availability cluster resource manager
Version:       1.1.8
Release:       %{pcmk_release}%{?dist}
License:       GPLv2+ and LGPLv2+
Url:           http://www.clusterlabs.org
Group:         System Environment/Daemons

# export VER={upstream_version}
# wget --no-check-certificate -O ClusterLabs-pacemaker-${VER}.tar.gz https://github.com/ClusterLabs/pacemaker/tarball/${VER}
Source0:       %{upstream_prefix}-%{upstream_version}.tar.gz
Patch1:        pacemaker-0b45588.patch
Patch2:        pacemaker-db9410b.patch
Patch3:        pacemaker-e69dfc1.patch
Patch4:        pacemaker-d20d06f.patch
Patch5:        pacemaker-ca7bf5e.patch
Patch98:       pcmk-plugin-warning.patch
Patch99:       pacemaker-no-doxygen.patch

BuildRoot:     %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
AutoReqProv:   on
Requires:      resource-agents
Requires:      %{name}-libs = %{version}-%{release}
Requires:      %{name}-cluster-libs = %{version}-%{release}
Requires:      %{name}-cli = %{version}-%{release}
Requires:      python >= 2.4

%if 0%{?rhel} > 0
ExclusiveArch: i686 x86_64
%endif

%if %{defined _unitdir}
# Needed for systemd unit
Requires(post):   systemd-sysv
Requires(post):   systemd-units
Requires(preun):  systemd-units
Requires(postun): systemd-units
%endif

%if %{with heartbeat}
Requires(pre): cluster-glue
%endif

%if %{with snmp}
Requires:      perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
%endif

%if 0%{?suse_version}
# net-snmp-devel on SLES10 does not suck in tcpd-devel automatically
BuildRequires: tcpd-devel
# Suse splits this off into a separate package
Requires:      python-curses python-xml
BuildRequires: python-curses python-xml
%endif

# Required for core functionality
BuildRequires: automake autoconf libtool pkgconfig python libtool-ltdl-devel
BuildRequires: glib2-devel libxml2-devel libxslt-devel libuuid-devel
BuildRequires: pkgconfig python-devel gcc-c++ bzip2-devel pam-devel

# We need reasonably recent versions of libqb for logging
BuildRequires: libqb-devel > 0.11.0
Requires:      libqb > 0.11.0

%if 0%{?suse_version} >= 1100
# Renamed since opensuse-11.0
BuildRequires:  libgnutls-devel
%else
BuildRequires:  gnutls-devel
%endif


# Enables optional functionality
BuildRequires: ncurses-devel openssl-devel libselinux-devel docbook-style-xsl
BuildRequires: bison byacc flex help2man

%if %{with cman}

%if 0%{?fedora} > 0
%if 0%{?fedora} < 17
BuildRequires: clusterlib-devel
%endif
%endif

%if 0%{?rhel} > 0
%if 0%{?rhel} < 7
BuildRequires: clusterlib-devel
%endif
%endif

%endif

%if %{with esmtp}
BuildRequires: libesmtp-devel
%endif

%if %{with snmp}
%ifarch alpha %{ix86} x86_64
BuildRequires: lm_sensors-devel
%endif

BuildRequires: net-snmp-devel
%endif

%if %{with corosync}
Requires:      corosync
BuildRequires: corosynclib-devel
%endif

%if %{with heartbeat}
# Do not require heartbeat, the admin should select which stack to use and install it
BuildRequires: cluster-glue-libs-devel heartbeat-devel heartbeat-libs >= 3.0.0
%endif

%if %{with stonithd}
BuildRequires: cluster-glue-libs-devel
%endif

%if !%{rawhide}
# More often than not, inkscape is busted on rawhide, don't even bother

%if %{with doc}
%ifarch %{ix86} x86_64
BuildRequires: publican inkscape asciidoc
%endif
%endif

%endif

%description
Pacemaker is an advanced, scalable High-Availability cluster resource
manager for Linux-HA (Heartbeat) and/or Corosync.

It supports "n-node" clusters with significant capabilities for
managing resources and dependencies.

It will run scripts at initialization, when machines go up or down,
when related resources fail and can be configured to periodically check
resource health.

Available rpmbuild rebuild options:
  --with(out) : heartbeat cman corosync doc publican snmp esmtp pre_release

%package cli
License:      GPLv2+ and LGPLv2+
Summary:      Command line tools for controlling Pacemaker clusters
Group:        System Environment/Daemons
Requires:     %{name}-libs = %{version}-%{release}
Requires:     perl-TimeDate

%description cli
Pacemaker is an advanced, scalable High-Availability cluster resource
manager for Linux-HA (Heartbeat) and/or Corosync.

The %{name}-cli package contains command line tools that can be used
to query and control the cluster from machines that may, or may not,
be part of the cluster.

%package -n %{name}-libs
License:      GPLv2+ and LGPLv2+
Summary:      Core Pacemaker libraries
Group:        System Environment/Daemons

%description -n %{name}-libs
Pacemaker is an advanced, scalable High-Availability cluster resource
manager for Linux-HA (Heartbeat) and/or Corosync.

The %{name}-libs package contains shared libraries needed for cluster
nodes and those just running the CLI tools.

%package -n %{name}-cluster-libs
License:      GPLv2+ and LGPLv2+
Summary:      Cluster Libraries used by Pacemaker
Group:        System Environment/Daemons
Requires:     %{name}-libs = %{version}-%{release}

%description -n %{name}-cluster-libs
Pacemaker is an advanced, scalable High-Availability cluster resource
manager for Linux-HA (Heartbeat) and/or Corosync.

The %{name}-cluster-libs package contains cluster-aware shared
libraries needed for nodes that will form part of the cluster nodes.

%package -n %{name}-libs-devel 
License:      GPLv2+ and LGPLv2+
Summary:      Pacemaker development package
Group:        Development/Libraries
Requires:     %{name}-cts = %{version}-%{release}
Requires:     %{name}-libs = %{version}-%{release}
Requires:     %{name}-cluster-libs = %{version}-%{release}
Requires:     libtool-ltdl-devel libqb-devel libuuid-devel libuuid-devel
Requires:     libxml2-devel libxslt-devel bzip2-devel glib2-devel 
%if %{with corosync}
Requires:     corosynclib-devel
%endif
%if %{with heartbeat}
Requires:     cluster-glue-libs-devel heartbeat-devel
%endif

%description -n %{name}-libs-devel
Pacemaker is an advanced, scalable High-Availability cluster resource
manager for Linux-HA (Heartbeat) and/or Corosync.

The %{name}-libs-devel package contains headers and shared libraries
for developing tools for Pacemaker.


%package      cts
License:      GPLv2+ and LGPLv2+
Summary:      Test framework for cluster-related technologies like Pacemaker
Group:        System Environment/Daemons
Requires:     python
Requires:     %{name}-libs = %{version}-%{release}

%description  cts
Test framework for cluster-related technologies like Pacemaker

%package      doc
License:      GPLv2+ and LGPLv2+
Summary:      Documentation for Pacemaker
Group:        Documentation

%description  doc
Documentation for Pacemaker.

Pacemaker is an advanced, scalable High-Availability cluster resource
manager for Linux-HA (Heartbeat) and/or Corosync.


%prep
%setup -q -n %{upstream_prefix}-%{upstream_version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%patch98 -p1
%patch99 -p1

# Force the local time
#
# Git sets the file date to the date of the last commit.
# This can result in files having been created in the future
# when building on machines in timezones 'behind' the one the 
# commit occurred in - which seriously confuses 'make'
find . -exec touch \{\} \;

%build
./autogen.sh

%if %{with snmp}
eval `objdump --headers --private-headers /usr/bin/perl | grep RPATH | awk '{print "export LD_LIBRARY_PATH="$2}'`
%endif

# RHEL <= 5 does not support --docdir
docdir=%{pcmk_docdir} %{configure}                 \
        %{!?with_heartbeat:  --without-heartbeat}  \
        %{!?with_corosync:   --without-ais}        \
        %{!?with_esmtp:      --without-esmtp}      \
        %{!?with_snmp:       --without-snmp}       \
        %{?with_cman:        --with-cman}          \
        %{?with_profiling:   --with-profiling}     \
        %{?with_gcov:        --with-gcov}          \
        --with-initdir=%{_initrddir}               \
        --localstatedir=%{_var}                    \
        --with-version=%{version}-%{release}

make %{_smp_mflags} V=1 docdir=%{pcmk_docdir} all

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} docdir=%{pcmk_docdir} V=1 install

mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig
mkdir -p ${RPM_BUILD_ROOT}%{_var}/lib/pacemaker/cores
install -m 644 mcp/pacemaker.sysconfig ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/pacemaker

# Scripts that should be executable
chmod a+x %{buildroot}/%{_datadir}/pacemaker/tests/cts/CTSlab.py

# These are not actually scripts
find %{buildroot} -name '*.xml' -type f -print0 | xargs -0 chmod a-x
find %{buildroot} -name '*.xsl' -type f -print0 | xargs -0 chmod a-x
find %{buildroot} -name '*.rng' -type f -print0 | xargs -0 chmod a-x
find %{buildroot} -name '*.dtd' -type f -print0 | xargs -0 chmod a-x
 
# Dont package static libs
find %{buildroot} -name '*.a' -type f -print0 | xargs -0 rm -f
find %{buildroot} -name '*.la' -type f -print0 | xargs -0 rm -f

# Do not package these either
rm -f %{buildroot}/%{_libdir}/service_crm.so

# The plugin is not supported, remove it
#rm -f %{buildroot}/%{_libexecdir}/lcrso/pacemaker.lcrso

%if %{with gcov}
GCOV_BASE=%{buildroot}/%{_var}/lib/pacemaker/gcov
mkdir -p $GCOV_BASE
find . -name '*.gcno' -type f | while read F ; do
        D=`dirname $F`
        mkdir -p ${GCOV_BASE}/$D
        cp $F ${GCOV_BASE}/$D
done
%endif

%clean
rm -rf %{buildroot}

%post
%if %{defined _unitdir}
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
%endif
/sbin/chkconfig --add pacemaker || :

%preun
if [ $1 -eq 0 ]; then
        # Package removal, not upgrade
        /sbin/service pacemaker stop &>/dev/null || :
        /sbin/chkconfig --del pacemaker || :
fi

%pre -n %{name}-libs
getent group %{gname} >/dev/null || groupadd -r %{gname}
getent passwd %{uname} >/dev/null || useradd -r -g %{gname} -s /sbin/nologin -c "cluster user" %{uname}
exit 0

%post -n %{name}-libs -p /sbin/ldconfig

%postun -n %{name}-libs -p /sbin/ldconfig

%post -n %{name}-cluster-libs -p /sbin/ldconfig

%postun -n %{name}-cluster-libs -p /sbin/ldconfig

%files
###########################################################
%defattr(-,root,root)

%exclude %{_datadir}/pacemaker/tests

%config(noreplace) %{_sysconfdir}/sysconfig/pacemaker
%if %{with corosync}
%{_sbindir}/pacemakerd
%{_initrddir}/pacemaker
%endif

%if %{defined _unitdir}
%{_unitdir}/pacemaker.service
%endif

%{_datadir}/pacemaker
%{_datadir}/snmp/mibs/PCMK-MIB.txt
%exclude %{_libexecdir}/pacemaker/lrmd_test
%{_libexecdir}/pacemaker/*
%{_libexecdir}/lcrso/pacemaker.lcrso

%if %{with heartbeat}
%{_libdir}/heartbeat/*
%endif

%{_sbindir}/crm_attribute
%{_sbindir}/crm_master
%{_sbindir}/crm_node
%{_sbindir}/attrd_updater
%{_sbindir}/fence_legacy
%{_sbindir}/fence_pcmk
%{_bindir}/ccs2cib
%{_bindir}/ccs_flatten
%{_bindir}/disable_rgmanager
%{_sbindir}/stonith_admin

%if %{with heartbeat}
%{_sbindir}/crm_uuid
%endif

%doc %{_mandir}/man7/*
%doc %{_mandir}/man8/attrd_updater.*
%doc %{_mandir}/man8/crm_attribute.*
%doc %{_mandir}/man8/crm_node.*
%doc %{_mandir}/man8/crm_master.*
%doc %{_mandir}/man8/fence_pcmk.*
%if %{with corosync}
%doc %{_mandir}/man8/pacemakerd.*
%endif
%doc %{_mandir}/man8/stonith_admin.*

%doc COPYING
%doc AUTHORS
%doc ChangeLog

%dir %attr (750, %{uname}, %{gname}) %{_var}/lib/pacemaker
%dir %attr (750, %{uname}, %{gname}) %{_var}/lib/pacemaker/cib
%dir %attr (750, %{uname}, %{gname}) %{_var}/lib/pacemaker/cores
%dir %attr (750, %{uname}, %{gname}) %{_var}/lib/pacemaker/pengine
%ghost %dir %attr (750, %{uname}, %{gname}) %{_var}/run/crm
%dir /usr/lib/ocf
%dir /usr/lib/ocf/resource.d
/usr/lib/ocf/resource.d/pacemaker

%files cli
%defattr(-,root,root)
%{_sbindir}/cibadmin
%{_sbindir}/crm_diff
%{_sbindir}/crm_error
%{_sbindir}/crm_failcount
%{_sbindir}/crm_mon
%{_sbindir}/crm_resource
%{_sbindir}/crm_standby
%{_sbindir}/crm_verify
%{_sbindir}/crmadmin
%{_sbindir}/iso8601
%{_sbindir}/crm_shadow
%{_sbindir}/crm_simulate
%{_sbindir}/crm_report
%{_sbindir}/crm_ticket
%doc %{_mandir}/man8/*
%exclude %{_mandir}/man8/attrd_updater.*
%exclude %{_mandir}/man8/crm_attribute.*
%exclude %{_mandir}/man8/crm_node.*
%exclude %{_mandir}/man8/crm_master.*
%exclude %{_mandir}/man8/fence_pcmk.*
%if %{with corosync}
%exclude %{_mandir}/man8/pacemakerd.*
%endif
%exclude %{_mandir}/man8/stonith_admin.*

%doc COPYING
%doc AUTHORS
%doc ChangeLog

%files -n %{name}-libs
%defattr(-,root,root)

%{_libdir}/libcib.so.*
%{_libdir}/liblrmd.so.*
%{_libdir}/libcrmservice.so.*
%{_libdir}/libcrmcommon.so.*
%{_libdir}/libpe_status.so.*
%{_libdir}/libpe_rules.so.*
%{_libdir}/libpengine.so.*
%{_libdir}/libstonithd.so.*
%{_libdir}/libtransitioner.so.*
%doc COPYING.LIB
%doc AUTHORS

%files -n %{name}-cluster-libs
%defattr(-,root,root)
%{_libdir}/libcrmcluster.so.*
%doc COPYING.LIB
%doc AUTHORS

%files doc
%defattr(-,root,root)
%doc %{pcmk_docdir}

%files cts
%defattr(-,root,root)
%{py_sitedir}/cts
%{_datadir}/pacemaker/tests/cts
%{_libexecdir}/pacemaker/lrmd_test
%doc COPYING.LIB
%doc AUTHORS

%files -n %{name}-libs-devel
%defattr(-,root,root)
%exclude %{_datadir}/pacemaker/tests/cts
%{_datadir}/pacemaker/tests
%{_includedir}/pacemaker
%{_libdir}/*.so
%if %{with gcov}
%{_var}/lib/pacemaker
%endif
%{_libdir}/pkgconfig/*.pc
%doc COPYING.LIB
%doc AUTHORS

%changelog
* Wed Jan 09 2013 Andrew Beekhof <abeekhof@redhat.com> - 1.1.8-7
- Resolves: rhbz#880249
- Update to upstream ca7bf5e

  + Fencing: Only try peers for non-topology based operations once
  + tools: Have crm_resource generate a valid transition key when sending resource commands to the crmd

* Sun Jan 06 2013 Andrew Beekhof <abeekhof@redhat.com> - 1.1.8-6
- Resolves: rhbz#877364
- Update to upstream d20d06f

  + cib: Avoid use-after-free by correctly support cib_no_children for non-xpath queries
  + cib: Remove text nodes from cib replace operations
  + Cluster: Preserve corosync membership state when matching node name/id entries
  + cman: Do not wait for unmanaged resources during shutdown
  + cman: Ensure reliable shutdown
  + cman: Ignore qdisk 'nodes'
  + Core: Prevent use-of_NULL in IPC code
  + corosync: Ensure peer state is preserved when matching names to nodeids
  + crmd: Avoid filling the ipc queue with data we don't need
  + crmd: Prevent election storms caused by getrusage() values being too close
  + Fencing: Correctly terminate when all device options have been exhausted
  + Fencing: Record delegated self-fencing operations in case they fail
  + legacy: Re-enable logging from the pacemaker plugin
  + pengine: Bug rhbz#880249 - Ensure orphan masters are demoted before being stopped
  + pengine: Bug rhbz#880249 - Teach the PE how to recover masters into primitives
  + pengine: Ensure previous migrations are completed before attempting another one
  + tools: crm_report - Fix node list detection

* Thu Dec 13 2012 Andrew Beekhof <abeekhof@redhat.com> - 1.1.8-5
- Resolves: rhbz#877364
- Update to upstream e69dfc1

  + attrd: Correctly handle deletion of non-existant attributes
  + cib: Do not pass local variables to mainloop_add_fd() when creating remote connections
  + Cluster: Do not strip the domain from node names calculated from uname(2)
  + Core: Supply the correct number of arguments for the format string
  + corosync: Avoid errors when closing failed connections
  + fencing: Automatically append 'nodeid' to fencing agent args if it is detected agent supports 'nodeid' parameter
  + mcp: chmod the correct directory instead of /var/run
  + pengine: Prevent double-free for cloned primitive from template

* Wed Oct 31 2012 Andrew Beekhof <abeekhof@redhat.com> - 1.1.8-4
- Resolves: rhbz#816875
- Update to upstream db9410b

  + Cluster: Detect node name collisions in corosync
  + Cluster: Strip domains from node names by default
  + Core: Prevent ordering changes when applying xml diffs
  + Fencing: On failure, only try a topology device once from the remote level.
  + Fencing: Retry stonith device for duration of action's timeout period.
  + Fencing: Support 'on_target' option in fencing device metadata for forcing unfence on target node
  + mcp: Re-attach to existing pacemaker components when mcp fails
  + pengine: Bug cl#5101 - Ensure stop order is preserved for partially active groups
  + pengine: Bug cl#5111 - When clone/master child rsc has on-fail=stop, insure all children stop on failure.
  + pengine: Correctly unpack active anonymous clones
  + pengine: Support a 'requires' resource meta-attribute for controlling whether it needs quorum, fencing or nothing
  + pengine: Support resources that require unfencing before start

* Tue Oct 2 2012 Andrew Beekhof <andrew@beekhof.net> 1.1.8-3
- Fix multilib support by turning off the auto compilation of python files
- Resolves: rhbz#816875

* Mon Oct 1 2012 Andrew Beekhof <andrew@beekhof.net> 1.1.8-2
- Fix internal package dependancies
- Resolves: rhbz#816875

- Update to upstream 0b45588
  + Correctly disable syslog output when requested 
  + Warn about node names containing a capital letter 
  + Do not start fencing until entire device topology is found or query results timeout.
  + Allow nodes to use a name other than uname() 

* Fri Sep 21 2012 Andrew Beekhof <andrew@beekhof.net> 1.1.8-1
- Rebuild for upstream 1.1.8 release
- Resolves: rhbz#816875 

- See included ChangeLog file or https://raw.github.com/ClusterLabs/pacemaker/master/ChangeLog for full details

  + New IPC implementation from libqb
  + New logging implementation from libqb
  + Quieter - info, debug and trace logs are no longer sent to syslog
  + Dropped dependancy on cluster-glue
  + Config and core directories no longer located in heartbeat directories
  + Support for managing systemd services
  + Rewritten local resource management daemon
  + Version bumps for every shared library due to API cleanups
  + Removes crm shell, install/use pcs shell and GUI instead

* Tue Apr 10 2012 David Vossel <dvossel@redhat.com> - 1.1.7-6
- Clear failcount history from crmd's lrm cache.
  Resolves: rhbz#789397

* Fri Mar 30 2012 David Vossel <dvossel@redhat.com> - 1.1.7-5
- Use default value for HB_DAEMON_DIR define when clusterglue does not provide one. 
  Resolves: rhbz#808557

* Tue Mar 27 2012 David Vossel <dvossel@redhat.com> - 1.1.7-3
- Add libqb-devel as a dependancy of pacemaker-libs-devel
- Medium: PE: Report resources as active in correct data about resource location
  Resolves:  rhbz#799070
- Low: Tools: Bug rhbz#801351 - Fix crm_report help text
  Resolves: rhbz#801351

* Thu Mar 1 2012 Andrew Beekhof <abeekhof@redhat.com> - 1.1.7-2
- Update patch level to upstream version: c26e624
- Resolves: rhbz#720214 rhbz#720218 rhbz#754216 rhbz#789397
  For full details, see:
    https://github.com/ClusterLabs/pacemaker/compare/c26e624...148fccf

* Thu Feb 16 2012 Andrew Beekhof <abeekhof@redhat.com> - 1.1.7-1
- Update tarball to upstream version: 148fccf
  See included ChangeLog file or, for full details:
    https://github.com/ClusterLabs/pacemaker/compare/148fccf...a12de08
- Add libqb-devel as a build dependancy
- Resolves: rhbz#782255 rhbz#754216 rhbz#729035 
- Related:  rhbz#790627

* Wed Oct 19 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.6-3
- Resolves: rhbz#745526

* Thu Oct 06 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.6-2
- Restore the ExclusiveArch directive
- Related: rhbz#743175

* Thu Oct 06 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.6-1
- Update tarball to upstream version: a02c0f1
  See included ChangeLog file or, for full details:
    https://github.com/ClusterLabs/pacemaker/compare/a12de08...a02c0f1
- Do not build in support for snmp, esmtp by default
- Create a package for cluster unaware libraries to minimze our footprint 
  on non-cluster nodes
- Better subpackage descriptions
- Resolves: rhbz#743175

* Mon Aug 08 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.5-8
- Update patch level to: 8ab3842021a5
- Resolves: rhbz#729035

* Mon Aug 08 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.5-7
- Fix install typo
- Related: rhbz#720136

* Mon Aug 08 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.5-6
- Update tarball to upstream version: b933cbea41b5
- Resolves: rhbz#708797
- Resolves: rhbz#451848
- Resolves: rhbz#708722 
- Resolves: rhbz#720136

* Fri Mar 25 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.5-5
- Fix another multi-lib header issue
- Related: rhbz#668466

* Fri Mar 25 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.5-4
- Fix multi-lib header issue
- Related: rhbz#668466

* Tue Mar 22 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.5-3
- Resolves: rhbz#684838 - Correctly notify fenced of a successful fencing event 

* Fri Mar 18 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.5-2
- Fix cman integration
- Resolves: rhbz#684838 - Correctly notify fenced of a successful fencing event 
- Resolves: rhbz#684825 - Ensure Pacemaker uses the most recent membership/quorum information 

* Thu Mar 10 2011 Andrew Beekhof <abeekhof@redhat.com> - 1.1.5-1
- Fix rpmlint warnings
- Rebase on new upstream release 
  See included ChangeLog file or http://hg.clusterlabs.org/pacemaker/1.1/file/tip/ChangeLog for details
  + Bugs lf#2445, lf#2493, lf#2508, lf#2518, lf#2527, lf#2544, 
         lf#2545, lf#2550, lf#2551, lf#2554, lf#2558, bnc#665131
- Resolves: rhbz#676286 - Add per device 'diag' option to pacemaker stonith action

* Fri Jan 14 2011 Andrew Beekhof <andrew@beekhof.net> 1.1.4-1
- Resolves: rhbz#668466
- Update tarball to upstream version: 3ac6ac993d6d
  + Performance improvements for larger clusters
  + Miscellaneous bug fixes

* Tue Jul 13 2010 Andrew Beekhof <andrew@beekhof.net> 1.1.2-7
- Resolves: rhbz#610815 - add cman support
  + High: ais: Use service slot 10 to avoid conflicting with cman

* Sat Jul 10 2010 Andrew Beekhof <andrew@beekhof.net> 1.1.2-6
- Resolves: rhbz#610815 - add cman support
  + High: cib: Also free query result for xpath operations that return more than one hit
  + High: cib: Fix the application of unversioned diffs
  + High: Core: Correctly unpack HA_Messages containing multiple entries with the same name
  + High: Core: Resolve coverity RESOURCE_LEAK defects
  + High: crmd: All nodes should see status updates, not just he DC
  + High: crmd: Allow non-DC nodes to clear failcounts too
  + High: crmd: Base DC election on process relative uptime
  + High: crmd: Make sure the membership cache is accurate after a sucessful fencing operation
  + High: crmd: Make sure we always poke the FSA after a transition to clear any TE_HALT actions
  + High: crmd: Prevent segmentation fault
  + High: PE: Avoid creating invalid ordering constraints for probes that are not needed
  + High: PE: Bug lf#1959 - Fail unmanaged resources should not prevent other services from shutting down
  + High: PE: Bug lf#2422 - Ordering dependencies on partially active groups not observed properly
  + High: PE: Bug lf#2424 - Use notify oepration definition if it exists in the configuration
  + High: PE: Bug lf#2433 - No services should be stopped until probes finish
  + High: PE: Correctly detect when there is a real failcount that expired and needs to be cleared
  + High: PE: Correctly handle pseudo action creation
  + High: PE: Fix colocation for interleaved clones
  + High: PE: Fix colocation with partially active groups
  + High: PE: Fix potential use-after-free defect from coverity
  + High: PE: Fix use-after-free in order_actions() reported by valgrind
  + High: PE: Prevent endless loop when looking for operation definitions in the configuration
  + High: stonith: Correctly parse pcmk_host_list parameters that appear on a single line
  + High: tools: crm_simulate - Resolve coverity USE_AFTER_FREE defect

* Tue May 25 2010 Andrew Beekhof <andrew@beekhof.net> 1.1.2-5
- Resolves: rhbz#594296 - rpmdiff checks
  + Remove legacy scripts
  + Add missing man pages
  + Fix sub-package version requires

* Tue May 18 2010 Andrew Beekhof <andrew@beekhof.net> 1.1.2-3
- Resolves: rhbz#590667
- Rebase on new upstream release
  + High: Core: Bug lf#2401 - Backed out changeset 6e6980376f01

* Wed May 12 2010 Andrew Beekhof <andrew@beekhof.net> 1.1.2-2
- Do not build on ppc and ppc64.
  Resolves: rhbz#590992
- Rebase on new upstream release
  + High: ais: Do not count votes from offline nodes and calculate current votes before sending quorum data
  + High: ais: Ensure the list of active processes sent to clients is always up-to-date
  + High: ais: Look for the correct conf variable for turning on file logging
  + High: ais: Use the threadsafe version of getpwnam
  + High: Core: Bug lf#2414 - Prevent use-after-free reported by valgrind when doing xpath based deletions
  + High: Core: fix memory leaks exposed by valgrind
  + High: crmd: Bug 2401 - Improved detection of partially active peers
  + High: crmd: Bug lf#2379 - Ensure the cluster terminates when the PE is not available
  + High: crmd: Bug lf#2414 - Prevent use-after-free of the PE connection after it dies
  + High: crmd: Bug lf#2414 - Prevent use-after-free of the stonith-ng connection
  + High: crmd: Do not allow the target_rc to be misused by resource agents
  + High: crmd: Do not ignore action timeouts based on FSA state
  + High: crmd: Ensure we dont get stuck in S_PENDING if we loose an election to someone that never talks to us again
  + High: crmd: Fix memory leaks exposed by valgrind
  + High: crmd: Remove race condition that could lead to multiple instances of a clone being active on a machine
  + High: crmd: Send erase_status_tag() calls to the local CIB when the DC is fenced, since there is no DC to accept them
  + High: crmd: Use global fencing notifications to prevent secondary fencing operations of the DC
  + High: PE: Bug lf#2317 - Avoid needless restart of primitive depending on a clone
  + High: PE: Bug lf#2361 - Ensure clones observe mandatory ordering constraints if the LHS is unrunnable
  + High: PE: Bug lf#2383 - Combine failcounts for all instances of an anonymous clone on a host
  + High: PE: Bug lf#2384 - Fix intra-set colocation and ordering
  + High: PE: Bug lf#2403 - Enforce mandatory promotion (colocation) constraints
  + High: PE: Bug lf#2412 - Correctly locate clone instances by their prefix
  + High: PE: Don ot be so quick to pull the trigger on nodes that are coming up
  + High: PE: Fix memory leaks exposed by valgrind
  + High: PE: Repair handling of unordered groups in RHS ordering constraints
  + High: PE: Rewrite native_merge_weights() to avoid Fix use-after-free
  + High: Shell: always reload status if working with the cluster (bnc#590035)
  + High: Shell: check timeouts also against the default-action-timeout property
  + High: Shell: Default to using the status section from the live CIB (bnc#592762)
  + High: Shell: edit multiple meta_attributes sets in resource management (lf#2315)
  + High: Shell: enable comments (lf#2221)
  + High: Tools: crm_mon - fix memory leaks exposed by valgrind

* Mon Mar 08 2010 Andrew Beekhof <andrew@beekhof.net> - 1.1.1-2
- Resolves: rhbz#570807 - Offline nodes should not have their quorum votes counted

* Thu Mar 04 2010 Andrew Beekhof <andrew@beekhof.net> - 1.1.1-1
- Resolves: rhbz#559868
- Split off the doc package as it has grown quite large
- Split off the cluster test suite (CTS) so that it can be used by other projects 
- Update the tarball from upstream to version 46e288ab9014
  + High: PE: Repair handling of unordered groups in RHS ordering constraints
  + High: Agents: Prevent shell expansion of '*' when there are files in /var/lib/heartbeat/cores/root
  + High: ais: Bug lf#2340 - Force rogue child processes to terminate after waiting 2.5 minutes
  + High: ais: Bug lf#2359 - Default expected votes to 2 inside Corosync/OpenAIS plugin
  + High: ais: Bug lf#2359 - expected-quorum-votes not correctly updated after membership change
  + High: ais: Bug rhbz#525552 - Move non-threadsafe calls to setenv() to after the fork()
  + High: crmd: Bug bnc#578644 - Improve handling of cancelled operations caused by resource cleanup
  + High: crmd: Make sure we wait for fencing to complete before continuing
  + High: crmd: Prevent use-of-NULL when non-DCs get stonith callbacks
  + High: Fencing: Account for stonith_get_info() always returning a pointer to the same static buffer
  + High: Fencing: Bug bnc#577007 - Correctly parse the hostlist output from stonith agents
  + High: Fencing: Correctly parse arg maps and do not return a provider for unknown agents
  + High: fencing: Fix can_fence_host_with_device() logic and improve hostlist output parsing
  + High: PE: Bug lf#2358 - Fix master-master anti-colocation
  + High: PE: Correctly implement optional colocation between primitives and clone resources
  + High: PE: Suppress duplicate ordering constraints to achieve orders of magnitude speed increases for large clusters
  + High: Shell: move scores from resource sets to the constraint element (lf#2331)
  + High: Shell: recovery from bad/outdated help index file
  + Medium: Shell: implement lifetime for rsc migrate and node standby (lf#2353)
  + Medium: Shell: node attributes update in configure (bnc#582767)

* Thu Feb 25 2010 Fabio M. Di Nitto <fdinitto@redhat.com> - 1.1.0-2
- Resolves: rhbz#568008
- Do not build pacemaker on s390 and s390x.

* Fri Jan 15 2010 Andrew Beekhof <andrew@beekhof.net> - 1.1.0-1
- Related: rhbz#543948
- Update the tarball from upstream to version 07ab245be519
  + High: crmd: Always connect to stonith
  + High: crmd: Ensure batch-limit is correctly enforced
  + High: crmd: Ensure we have the latest status after a transition abort
  + High: Fencing: Overhaul the fencing daemon
  + High: PE: Bug lf#2153 - non-clones shouldn't restart when clones stop/start on other nodes - improved
  + Medium: PE: Allow resource sets to be reused between ordering and colocation constraints
  + Medium: PE: Implement serializing order constraints that dont cause restarts or inhibit migration
  + Medium: PE: Include node attributes for the node to be fenced
  + Medium: PE: Make crm_simulate a full replacement for ptest
  + Medium: PE: Only complain about target-role=master for non m/s resources
  + Medium: PE: Prevent non-multistate resources from being promoted through target-role
  + Medium: PE: Simplify the rsc_order syntax - don't make funky inferences based on score
  + Medium: PE: Support serialized sets of resources
  + Medium: Tools: Bug lf#2286 - Allow the shell to accept template parameters on the command line
  + Medium: Tools: Bug lf#2307 - Provide a way to determin the nodeid of past cluster members
  + Medium: Tools: crm: add update method to template apply (LF 2289)
  + Medium: Tools: crm: direct RA interface for stonith class resource agents (LF 2270)
  + Medium: Tools: crm: don't remove sets which contain id-ref attribute (LF 2304)
  + Medium: Tools: crm: exclude locations when testing for pathological constraints (LF 2300)
  + Medium: Tools: crm: fix exit code on single shot commands
  + Medium: Tools: crm: fix node delete (LF 2305)
  + Medium: Tools: crm: implement -F (--force) option
  + Medium: Tools: crm: rename status to cibstatus (LF 2236)
  + Medium: Tools: crm: stay in crm if user specified level only (LF 2286)

* Tue Dec 15 2009 Andrew Beekhof <andrew@beekhof.net> - 1.1.0-0.1-00d9bcac8775.hg
- Related: rhbz#rhbz#543948
- Update the tarball from upstream to version 00d9bcac8775
  + High: PE: Bug 2213 - Ensure groups process location constraints so that clone-node-max works for cloned groups
  + High: PE: Bug lf#2153 - Update regression tests
  + High: PE: Bug lf#2153 - non-clones shouldn't restart when clones stop/start on other nodes
  + High: PE: Bug lf#2209 - Clone ordering should be able to prevent startup of dependant clones
  + High: PE: Bug lf#2216 - Correctly identify the state of anonymous clones when deciding when to probe
  + High: PE: Bug lf#2225 - Operations that require fencing should wait for 'stonith_complete' not 'all_stopped'.
  + High: PE: Bug lf#2225 - Prevent clone peers from stopping while another is instance is (potentially) being fenced
  + High: PE: Correctly anti-colocate with a group
  + High: PE: Correctly unpack ordering constraints for resource sets to avoid graph loops
  + High: Replace stonithd with the new fencing subsystem
  + High: cib: Ensure the loop searching for a remote login message terminates
  + High: cib: Finally fix reliability of receiving large messages over remote plaintext connections
  + High: cib: Fix remote notifications
  + High: cib: For remote connections, default to CRM_DAEMON_USER since thats the only one that the cib can validate the password for using PAM
  + High: cib: Remote plaintext - Retry sending parts of the message that didn't fit the first time
  + Medium: PE: Bug lf#2206 - rsc_order constraints always use score at the top level
  + Medium: PE: Provide a default action for resource-set ordering
  + Medium: PE: Silently fix requires=fencing for stonith resources so that it can be set in op_defaults
  + Medium: ais: Some clients such as gfs_controld want a cluster name, allow one to be specified in corosync.conf
  + Medium: cib: Create valid notification control messages
  + Medium: cib: Indicate where the remote connection came from
  + Medium: cib: Send password prompt to stderr so that stdout can be redirected
  + Medium: extra: Add the daemon parameter to the controld metadata
  + Medium: fencing: Re-engineer the stonith daemon to support RHCS agents
  + Medium: tools: Make crm_mon functional with remote connections
  + Medium: xml: Bug bnc#552713 - Treat node unames as text fields not IDs
  + Medium: xml: Bug lf#2215 - Create an always-true expression for empty rules when upgrading from 0.6

* Thu Dec 03 2009 Dennis Gregorovic <dgregor@redhat.com> - 1.0.5-6.2
- Rebuilt for RHEL 6

* Wed Nov 25 2009 Dennis Gregorovic <dgregor@redhat.com> - 1.0.5-6.1
- Rebuilt for RHEL 6

* Sat Oct 31 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.5-6
- Let snmp automatically pull in lm_sensors-devel if required
  and available on that arch (its not on s390x)

* Sat Oct 31 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.5-5
- Disable Heartbeat support

* Thu Oct 29 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.5-4
- Include the fixes from CoroSync integration testing
- Move the resource templates - they're not documentation
- Ensure documentation is placed in a standard location
- Exclude documentation that is included elsewhere in the package

- Update the tarball from upstream to version ee19d8e83c2a
  + High: cib: Correctly clean up when both plaintext and tls remote ports are requested
  + High: PE: Bug bnc#515172 - Provide better defaults for lt(e) and gt(e) comparisions
  + High: PE: Bug lf#2197 - Allow master instances placemaker to be influenced by colocation constraints
  + High: PE: Make sure promote/demote pseudo actions are created correctly
  + High: PE: Prevent target-role from promoting more than master-max instances
  + High: ais: Bug lf#2199 - Prevent expected-quorum-votes from being populated with garbage
  + High: ais: Prevent deadlock - dont try to release IPC message if the connection failed
  + High: cib: For validation errors, send back the full CIB so the client can display the errors
  + High: cib: Prevent use-after-free for remote plaintext connections
  + High: crmd: Bug lf#2201 - Prevent use-of-NULL when running heartbeat

* Wed Oct 13 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.5-3
- Update the tarball from upstream to version 38cd629e5c3c
  + High: Core: Bug lf#2169 - Allow dtd/schema validation to be disabled
  + High: PE: Bug lf#2106 - Not all anonymous clone children are restarted after configuration change
  + High: PE: Bug lf#2170 - stop-all-resources option had no effect
  + High: PE: Bug lf#2171 - Prevent groups from starting if they depend on a complex resource which can't
  + High: PE: Disable resource management if stonith-enabled=true and no stonith resources are defined
  + High: PE: Don't include master score if it would prevent allocation
  + High: ais: Avoid excessive load by checking for dead children every 1s (instead of 100ms)
  + High: ais: Bug rh#525589 - Prevent shutdown deadlocks when running on CoroSync
  + High: ais: Gracefully handle changes to the AIS nodeid
  + High: crmd: Bug bnc#527530 - Wait for the transition to complete before leaving S_TRANSITION_ENGINE
  + High: crmd: Prevent use-after-free with LOG_DEBUG_3
  + Medium: xml: Mask the "symmetrical" attribute on rsc_colocation constraints (bnc#540672)
  + Medium (bnc#520707): Tools: crm: new templates ocfs2 and clvm
  + Medium: Build: Invert the disable ais/heartbeat logic so that --without (ais|heartbeat) is available to rpmbuild
  + Medium: PE: Bug lf#2178 - Indicate unmanaged clones
  + Medium: PE: Bug lf#2180 - Include node information for all failed ops
  + Medium: PE: Bug lf#2189 - Incorrect error message when unpacking simple ordering constraint
  + Medium: PE: Correctly log resources that would like to start but can't
  + Medium: PE: Stop ptest from logging to syslog
  + Medium: ais: Include version details in plugin name
  + Medium: crmd: Requery the resource metadata after every start operation

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 1.0.5-2.1
- rebuilt with new openssl

* Wed Aug 19 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.5-2
- Add versioned perl dependancy as specified by
    https://fedoraproject.org/wiki/Packaging/Perl#Packages_that_link_to_libperl
- No longer remove RPATH data, it prevents us finding libperl.so and no other
  libraries were being hardcoded
- Compile in support for heartbeat
- Conditionally add heartbeat-devel and corosynclib-devel to the -devel requirements 
  depending on which stacks are supported

* Mon Aug 17 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.5-1
- Add dependancy on resource-agents
- Use the version of the configure macro that supplies --prefix, --libdir, etc
- Update the tarball from upstream to version 462f1569a437 (Pacemaker 1.0.5 final)
  + High: Tools: crm_resource - Advertise --move instead of --migrate
  + Medium: Extra: New node connectivity RA that uses system ping and attrd_updater
  + Medium: crmd: Note that dc-deadtime can be used to mask the brokeness of some switches

* Tue Aug 11 2009 Ville Skyttä <ville.skytta@iki.fi> - 1.0.5-0.7.c9120a53a6ae.hg
- Use bzipped upstream tarball.

* Wed Jul  29 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.5-0.6.c9120a53a6ae.hg
- Add back missing build auto* dependancies
- Minor cleanups to the install directive

* Tue Jul  28 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.5-0.5.c9120a53a6ae.hg
- Add a leading zero to the revision when alphatag is used

* Tue Jul  28 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.5-0.4.c9120a53a6ae.hg
- Incorporate the feedback from the cluster-glue review
- Realistically, the version is a 1.0.5 pre-release
- Use the global directive instead of define for variables
- Use the haclient/hacluster group/user instead of daemon
- Use the _configure macro
- Fix install dependancies

* Fri Jul  24 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.4-3
- Include an AUTHORS and license file in each package
- Change the library package name to pacemaker-libs to be more 
  Fedora compliant
- Remove execute permissions from xml related files
- Reference the new cluster-glue devel package name
- Update the tarball from upstream to version c9120a53a6ae
  + High: PE: Only prevent migration if the clone dependancy is stopping/starting on the target node
  + High: PE: Bug 2160 - Dont shuffle clones due to colocation
  + High: PE: New implementation of the resource migration (not stop/start) logic
  + Medium: Tools: crm_resource - Prevent use-of-NULL by requiring a resource name for the -A and -a options
  + Medium: PE: Prevent use-of-NULL in find_first_action()
  + Low: Build: Include licensing files

* Tue Jul 14 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.4-2
- Reference authors from the project AUTHORS file instead of listing in description
- Change Source0 to reference the project's Mercurial repo
- Cleaned up the summaries and descriptions
- Incorporate the results of Fedora package self-review

* Tue Jul 14 2009 Andrew Beekhof <andrew@beekhof.net> - 1.0.4-1
- Initial checkin
